import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import React, { useCallback, useMemo } from 'react';
import { Typography } from '@mui/material';
import AdminSpinner from '../../spinner/AdminSpinner';
import NoResultFound from '../NoResultFound';
import './mobileTable-styles.scss';
const MobileTable = (props) => {
    const { rows = [], isLoading, handleRowClick, columns } = props;
    const handleCardClick = useCallback((row) => () => {
        const rowData = { id: row?.id, row };
        handleRowClick && handleRowClick(rowData);
    }, [handleRowClick]);
    const renderValue = useCallback((value) => {
        if (typeof value === 'string') {
            return value.length > 40 ? `${value.slice(0, 40)}...` : value;
        }
        else if (typeof value === 'number') {
            return value.toString();
        }
        else {
            return '-';
        }
    }, []);
    const getHeaderName = useCallback((key) => {
        return columns.find(column => column.field === key)?.headerName;
    }, [columns]);
    const visibleColumns = useMemo(() => {
        return columns.filter(column => column.isVisible !== false);
    }, [columns]);
    const renderRows = useCallback(() => {
        return rows.map(row => (_jsx("div", { className: "mobileTable__row", onClick: handleCardClick(row), children: visibleColumns.map(column => {
                const key = column.field;
                const value = row[key];
                return (_jsxs("div", { className: "mobileTable__rowItem", children: [_jsx(Typography, { className: "mobileTable__rowItemKey", children: getHeaderName(key) || key }), _jsx(Typography, { className: "mobileTable__rowItemValue", children: renderValue(value || '') })] }, key));
            }) }, row?.id)));
    }, [rows, visibleColumns, handleCardClick, getHeaderName, renderValue]);
    if (isLoading) {
        return _jsx(AdminSpinner, {});
    }
    return (_jsxs("div", { className: "mobileTable__container", children: [!rows?.length && _jsx(NoResultFound, {}), renderRows()] }));
};
export default React.memo(MobileTable);
