import dayjs from 'dayjs';
import { z } from 'zod';
import PeopleAltIcon from '@mui/icons-material/PeopleAlt';
import { DateFormat, EditApiMethod, FieldEnum, ROUTES, TableCellType } from '../../constants';
import { PaginationMethod } from '../../types/common-types';
var RewardField;
(function (RewardField) {
    RewardField["RewardUrl"] = "reward_url";
    RewardField["Rewards"] = "rewards";
    RewardField["DATE"] = "date";
    RewardField["Status"] = "is_active";
})(RewardField || (RewardField = {}));
const RewardSchema = z.object({
    [RewardField.RewardUrl]: z.any().optional(),
    [RewardField.Rewards]: z.array(z.any()).optional(),
    [RewardField.DATE]: z.optional(z.string()).optional(),
    [RewardField.Status]: z.boolean().optional(),
});
export const DATA = {
    title: 'Rewards',
    tables: [
        {
            key: 'rewards',
            detailsRoute: ROUTES.DEMO_DETAILS,
            editApiMethod: EditApiMethod.PUT,
            toggleKey: 'is_active',
            formatData: (data) => {
                const updatedData = data.map(item => {
                    return {
                        ...item,
                        reward_url: {
                            rows: 2,
                            cols: 2,
                            min_range: 1,
                            max_range: 7,
                            qualification_percentage: 10,
                            game_timer: 10,
                        },
                    };
                });
                return updatedData;
            },
            apiEndPoint: {
                ALL: 'https://66a3354844aa637045805c36.mockapi.io/rewards',
            },
            handleDetailsSubmit: async (data) => {
                console.log('res009', data);
                return data;
            },
            columns: [
                {
                    field: RewardField.RewardUrl,
                    headerName: "Reward's URL",
                    sortable: true,
                    isVisible: false,
                    filterProps: {
                        fieldType: FieldEnum.Text,
                    },
                },
                {
                    field: RewardField.Rewards,
                    headerName: 'Rewards',
                    fieldProps: {
                        fieldType: FieldEnum.ChipInput,
                        infoMessage: 'Select rewards',
                    },
                },
                {
                    field: RewardField.DATE,
                    headerName: 'Rewards',
                    renderCellProps: {
                        type: TableCellType.DATE_TIME,
                    },
                    fieldProps: {
                        fieldType: FieldEnum.DateTime,
                        dateFormat: DateFormat.ISO8601,
                        minDate: dayjs(),
                    },
                },
            ],
            enableExport: true,
            actions: {
                edit: true,
                delete: true,
                view: true,
                add: true,
                filter: true,
                search: false,
                toggle: true,
            },
            customActions: [
                {
                    label: 'Activate',
                    key: 'activate',
                    handleClick: (row) => {
                        console.log('Activate', row);
                    },
                    showInMenu: false,
                    Icon: PeopleAltIcon,
                },
            ],
            pagination: false,
            paginationMethod: PaginationMethod.OFFSET,
            schema: RewardSchema,
            defaultValues: {
                [RewardField.RewardUrl]: '',
            },
        },
    ],
};
