import axios from 'axios';
import { isNil, omitBy } from 'lodash';
import { API } from './api-constants';
export var HttpVerb;
(function (HttpVerb) {
    HttpVerb["GET"] = "GET";
    HttpVerb["POST"] = "POST";
    HttpVerb["PUT"] = "PUT";
    HttpVerb["PATCH"] = "PATCH";
    HttpVerb["DELETE"] = "DELETE";
})(HttpVerb || (HttpVerb = {}));
const axiosConfig = (authToken, params) => ({
    baseURL: API.baseUrl,
    timeout: 6000000,
    headers: {
        Authorization: `Bearer ${authToken}`,
    },
    params,
    // need to check for this any type in queryParams
    paramsSerializer(queryParams) {
        const paramsWithValues = omitBy(queryParams, isNil);
        return Object.entries(paramsWithValues)
            .flatMap(([key, value]) => {
            if (Array.isArray(value)) {
                return value.map(v => `${encodeURIComponent(key)}=${encodeURIComponent(v)}`);
            }
            return `${encodeURIComponent(key)}=${encodeURIComponent(value)}`;
        })
            .join('&');
    },
});
const mapAxiosResponseToLocalResponseType = (axiosResponse) => {
    return {
        code: axiosResponse.status,
        message: axiosResponse.statusText,
        data: axiosResponse.data,
    };
};
const errorResponse = (errorCode, errorMessage, data) => ({
    code: errorCode,
    message: errorMessage,
    data,
});
const getApiResponseUsingRequestVerb = async (requestVerb, endpoint, requestData, configParam, contentType, getIdToken, isTokenRequired = true) => {
    const accessToken = getIdToken && getIdToken();
    const authToken = !!accessToken && isTokenRequired ? accessToken : '';
    const { params, data } = configParam || {};
    const config = axiosConfig(authToken, params);
    if (contentType) {
        const header = { ...config.headers, 'Content-Type': contentType };
        config.headers = header;
    }
    switch (requestVerb) {
        case HttpVerb.GET:
            return axios.get(endpoint, config);
        case HttpVerb.POST:
            return axios.post(endpoint, requestData, config);
        case HttpVerb.PUT:
            return axios.put(endpoint, requestData, config);
        case HttpVerb.PATCH:
            return axios.patch(endpoint, requestData, config);
        case HttpVerb.DELETE:
            return axios.delete(endpoint, { ...config, data });
        default: {
            return Promise.resolve(null);
        }
    }
};
export const makeApiCall = async (requestVerb, endpoint, requestData, configParam, contentType, getIdToken, isTokenRequired) => {
    try {
        const response = await getApiResponseUsingRequestVerb(requestVerb, endpoint, requestData, configParam, contentType, getIdToken, isTokenRequired ?? true);
        if (response?.status) {
            return mapAxiosResponseToLocalResponseType(response);
        }
        return errorResponse(500, 'Could not get a response from the API');
    }
    catch (exception) {
        throw new Error(exception);
    }
};
