import type { DefaultValues, FieldValues, Path } from 'react-hook-form';
import type { Schema } from 'zod';
import type { DataGridProps, GridColDef, GridRowParams, GridRowsProp } from '@mui/x-data-grid';
import { IAdminAnimatedStatusProps } from '../components/animated-status/AdminAnimatedStatus';
import { IAdminAvatarProps } from '../components/avatar/AdminAvatar';
import { IAdminChipProps } from '../components/chip/AdminChip';
import { type FieldPropsType } from '../components/form/AdminForm';
import { EditApiMethod } from '../constants';
import { TableAction, TableCellType } from '../constants/table-constants';
import { IAdminTableFromCrudProps, IAdminTableFromLayoutProps, IFooterFromCrudProps, IFooterFromLayoutProps, IRow } from './table-types';
export interface IRenderCellPropsBase {
    type?: TableCellType;
}
export type IRenderCellProps = (IRenderCellPropsBase & ({
    type: TableCellType.IMAGE;
} & Partial<{
    value: string;
}>)) | ({
    type: TableCellType.TEXT;
} & Partial<{
    value: string;
}>) | ({
    type: TableCellType.CHIP;
} & Partial<IAdminChipProps>) | ({
    type: TableCellType.ANIMATED_STATUS;
} & Partial<IAdminAnimatedStatusProps>) | ({
    type: TableCellType.BOOLEAN;
} & Partial<{
    value: boolean;
}>) | ({
    type: TableCellType.DATE;
} & Partial<{
    value: string;
}>) | ({
    type: TableCellType.DATE_TIME;
} & Partial<{
    value: string;
}>) | ({
    type: TableCellType.AVATAR;
} & Partial<IAdminAvatarProps>);
export type IGridCol<SubmitDataType extends FieldValues> = GridColDef<SubmitDataType> & {
    field: Path<SubmitDataType>;
};
export type IColumn<SubmitDataType extends FieldValues> = {
    fieldProps?: FieldPropsType;
    filterProps?: FieldPropsType;
    renderCellProps?: IRenderCellProps;
    isVisible?: boolean;
    errorMessage?: string;
} & IGridCol<SubmitDataType>;
export interface IActions {
    add: boolean;
    delete: boolean;
    edit: boolean;
    view: boolean;
    filter: boolean;
    search: boolean;
    toggle: boolean;
}
export interface IApiEndPoints {
    ALL?: string;
    POST?: string;
    PUT?: string;
    DELETE?: string;
    GET?: string;
    PATCH?: string;
    TOGGLE?: string;
}
export interface ITableProps<SubmitDataType extends FieldValues> extends Omit<DataGridProps<SubmitDataType>, 'pagination' | 'columns' | 'rows'>, IAdminTableFromLayoutProps<SubmitDataType>, IFooterFromLayoutProps {
    actions: IActions;
    apiEndPoint?: IApiEndPoints;
    customActions?: TableAction[];
    defaultValues: DefaultValues<SubmitDataType>;
    detailsRoute: string;
    editApiMethod?: EditApiMethod;
    actionDisableForRow?: (row: IRow) => boolean;
    enableExport?: boolean;
    formatData?: (data: Partial<SubmitDataType>[]) => Partial<SubmitDataType>[];
    handleDetailsSubmit?: (data: SubmitDataType, type?: 'add' | 'edit') => Promise<SubmitDataType>;
    key: string;
    paginationMethod?: PaginationMethod;
    schema: Schema;
    subTitle?: string;
    toggleKey?: string;
}
export interface IJsonData<SubmitDataType extends FieldValues> {
    tables: ITableProps<SubmitDataType>[];
    title: string;
}
interface IHeaderActionFromCrud {
    handleAddClick: () => void;
    handleFilter?: () => void;
    appliedFilters: any;
}
export interface ICrudProps<SubmitDataType extends FieldValues> extends IFooterFromCrudProps, IAdminTableFromCrudProps<SubmitDataType>, IHeaderActionFromCrud {
    rows: GridRowsProp<SubmitDataType>;
    handleSearch: (value: string | number) => void;
    searchValue: string | number;
    handleToggle: (row: IRow) => void;
    disableActionsForRow: (row: IRow) => void;
}
export interface ILayoutProps<SubmitDataType extends FieldValues> {
    data: ITableProps<SubmitDataType>;
    title: string;
    handleCustomRowClick?: (data: GridRowParams<SubmitDataType>) => void;
}
export interface IWithCrudProps<SubmitDataType extends FieldValues> {
    data: IJsonData<SubmitDataType>;
    handleCustomRowClick?: (data: GridRowParams<SubmitDataType>) => void;
}
export interface IDetailsComponent<SubmitDataType extends FieldValues> {
    details: ITableProps<SubmitDataType>;
    isSecondaryButton?: boolean;
    secondaryButtonLabel?: string;
    handleSecondaryButtonClick?: () => void;
}
export declare enum PaginationMethod {
    OFFSET = "offset",
    PAGE = "page"
}
export {};
